Crate sigma_compiler

Crate sigma_compiler 

See the documentation for sigma_compiler! for details.

Re-exports

pub use group;
pub use rand;
pub use sigma_proofs;
pub use subtle;

Modules

rangeutils
A module containing some utility functions useful for the runtime processing of range statements.
vecutils
A module containing some utility functions useful for the runtime processing of vector operations.

Macros

sigma_compiler
The main macro provided by the sigma_compiler crate.
sigma_compiler_prover
A version of the sigma_compiler! macro that only outputs the code needed by the prover.
sigma_compiler_verifier
A version of the sigma_compiler! macro that only outputs the code needed by the verifier.